==> jsonstreamreader-1.1.8.tar.gz: lib/complexexpression.dart <==
import 'jsonexpression.dart';
import 'dart:math';

import 'booleanparser.dart';

///Combinations of JsonExpression
class ComplexExpression {
  String _expression;
  List<List<String>> _parsedExpression;
  Map<String, JsonExpression> _map = new Map<String, JsonExpression>();
  ComplexExpression(String expression) {
    String regex = "((?<=\\))|(?=\\)))|((?<=\\()|(?=\\())|\\s";
    Iterable<Match> matches = new RegExp(r"\{(.*)\}").allMatches(expression);
    matches.forEach((Match m) {
      String replacement = '{' +
          m
              .group(1)
              .replaceAll(new RegExp(r"[\s]+"), ' ')
              .split(" ")
              .join(",") +
          '}';
      expression = expression.replaceAll('{' + m.group(1) + '}', replacement);
    });
    this._expression = expression
        .replaceAll(new RegExp(r"[\s]+"), ' ')
        .trim()
        .split(new RegExp(regex))
        .map((String simple) {
      simple = simple.trim();
      if (simple == '(' ||
          simple == ')' ||
          simple == '&' ||
          simple == '|' ||
          simple == ' ') {
        return simple;
      } else {
        var random = new Random();
        String key = random.nextInt(10000).toString();
        _map[key] = new JsonExpression(simple);
        return key;
      }
    }).join(" ");
    BooleanParser parser = new BooleanParser();
    _parsedExpression = parser.parse(this._expression);
  }
  String data() {
    return this._expression;
  }

  map() {
    return _map;
  }

  bool evaluate(List<String> keys, String key) {
    List<bool> conditions = this._parsedExpression.map((List<String> item) {
      return item.every((String i) {
        return this._map[i].evaluate(keys, key);
      });
    }).toList();
    return conditions.reduce((bool first, bool second) {
      return first || second;
    });
  }
}

==> jsonstreamreader-1.1.9.tar.gz: lib/complexexpression.dart <==
import 'jsonexpression.dart';
import 'dart:math';

import 'booleanparser.dart';

///Combinations of JsonExpression
class ComplexExpression {
  String _expression;
  List<List<String>> _parsedExpression;
  Map<String, JsonExpression> _map = new Map<String, JsonExpression>();
  ComplexExpression(String expression) {
    String regex = "((?<=\\))|(?=\\)))|((?<=\\()|(?=\\())|\\s";
    Iterable<Match> matches = new RegExp(r"\{(.*)\}").allMatches(expression);
    matches.forEach((Match m) {
      String replacement = '{' +
          m
              .group(1)
              .replaceAll(new RegExp(r"[\s]+"), ' ')
              .split(" ")
              .join(",") +
          '}';
      expression = expression.replaceAll('{' + m.group(1) + '}', replacement);
    });
    this._expression = expression
        .replaceAll(new RegExp(r"[\s]+"), ' ')
        .trim()
        .split(new RegExp(regex))
        .map((String simple) {
      simple = simple.trim();
      if (simple == '(' ||
          simple == ')' ||
          simple == '&' ||
          simple == '|' ||
          simple == ' ') {
        return simple;
      } else {
        var random = new Random();
        String key = random.nextInt(10000).toString();
        _map[key] = new JsonExpression(simple);
        return key;
      }
    }).join(" ");
    BooleanParser parser = new BooleanParser();
    _parsedExpression = parser.parse(this._expression);
  }
  String data() {
    return this._expression;
  }

  map() {
    return _map;
  }

  bool evaluate(Iterable<String> keys, String key) {
    List<bool> conditions = this._parsedExpression.map((List<String> item) {
      return item.every((String i) {
        return this._map[i].evaluate(keys, key);
      });
    }).toList();
    return conditions.reduce((bool first, bool second) {
      return first || second;
    });
  }
}
